mirror of
https://github.com/ROCm/composable_kernel.git
synced 2026-07-17 17:19:12 +00:00
fixed a bug in the ckProfiler, and formatted the code
This commit is contained in:
@@ -20,7 +20,7 @@ struct pk_i4_t
|
||||
__host__ __device__ constexpr pk_i4_t() : data{type{}} {}
|
||||
__host__ __device__ constexpr pk_i4_t(type init) : data{init} {}
|
||||
|
||||
__host__ __device__ constexpr operator float() const { return static_cast<float>(data); }
|
||||
__host__ __device__ constexpr operator float() const { return static_cast<int8_t>(data); }
|
||||
};
|
||||
|
||||
inline constexpr auto next_pow2(uint32_t x)
|
||||
|
||||
@@ -342,7 +342,7 @@ bool profile_gemm_b_scale_impl(int do_verification,
|
||||
if(do_log)
|
||||
{
|
||||
LogRangeAsType<float>(std::cout << "a : ", a_m_k.mData, ",") << std::endl;
|
||||
LogRangeAsType<float>(std::cout << "b: ", b_k_n.mData, ",") << std::endl;
|
||||
LogRangeAsType<int8_t>(std::cout << "b: ", b_k_n.mData, ",") << std::endl;
|
||||
LogRangeAsType<float>(
|
||||
std::cout << "c_host : ", c_m_n_host_result.mData, ",")
|
||||
<< std::endl;
|
||||
|
||||
@@ -103,9 +103,9 @@ int profile_gemm_b_scale(int argc, char* argv[])
|
||||
printf("n_warmup:%d, n_iter:%d, rotating:%lu\n", n_warmup, n_iter, rotating);
|
||||
}
|
||||
|
||||
using F32 = float;
|
||||
using F16 = ck::half_t;
|
||||
using I4 = ck::pk_i4_t;
|
||||
using F32 = float;
|
||||
using F16 = ck::half_t;
|
||||
using I4 = ck::pk_i4_t;
|
||||
|
||||
using Row = ck::tensor_layout::gemm::RowMajor;
|
||||
using Col = ck::tensor_layout::gemm::ColumnMajor;
|
||||
|
||||
Reference in New Issue
Block a user